Demonstrate the use of custom, User Defined Models with Bokeh Server app. This demo
has a custom tile renderer that selects a tile provider at random for every tile 
displayed. 

#### Running

To view the app directly from a Bokeh server, navigate to the parent
directory [`examples/app`](https://github.com/bokeh/bokeh/tree/master/examples/app), 
and execute the command:

    bokeh serve --show random_tiles
